import { FormField } from "../inputTypes";
import { UnregisterOptions } from "./useEffectFieldUnregisterOnUnmount";
interface SharedProps {
    /**
     * The form field that the input is bound to.
     *
     * Central configurations like the name of the field, label and validations
     *  are stored here.
     */
    formField: FormField;
    /**
     * If true, the field will unregister when the component unmounts. In that
     * case additional options for handling the unregistering can be passed in.
     *
     * @default false
     */
    isUnregisteringOnUnmount?: boolean;
}
interface UnregisterOnUnmountProps extends SharedProps {
    isUnregisteringOnUnmount?: true;
    /**
     * Options for handling the current state when unregistering the field.
     *
     * Documentation: https://react-hook-form.com/docs/useform/unregister.
     */
    unregisterOptions?: UnregisterOptions;
}
interface DontUnregisterOnUnmountProps extends SharedProps {
    isUnregisteringOnUnmount?: false;
    unregisterOptions?: never;
}
export type BaseInputProps<T> = (T & UnregisterOnUnmountProps) | (T & DontUnregisterOnUnmountProps);
export {};
