import { FormEvent } from "react";
export type FormSubmitHandlerAsync = (event?: FormEvent) => Promise<void>;
export type FormSubmitHandler = (event?: FormEvent) => void;
/**
 * Turn an async submitHandler into a synchronous one.
 *
 * Reasoning:
 * - we're often talking to the API during form submission. The onSubmit handler will be returning a Promise in this case.
 * - the `form` element, per definition, always expects a synchronous function.
 * - creating on inline function in every form is a bit clumsy, and does not look clean.
 *
 * Then/catch cases should be properly handled by the submit handler itself,
 *  the catch supplied here is only a last safety net against an "unhandled promise rejection" error.
 */
export declare const syncSubmit: (asyncSubmitHandler: FormSubmitHandlerAsync) => FormSubmitHandler;
