import { FieldPath, FieldValues, useFieldArray, UseFormProps, UseFormReturn } from "react-hook-form";
/**
 * Gets a TypeScript-validated field name.
 */
export type FieldNameGetter<TFieldValues extends FieldValues> = (fieldName: FieldPath<TFieldValues>) => FieldPath<TFieldValues>;
/**
 * Not sure what this represents,
 *  but it's the seconds generic argument in RHFs type declarations.
 *
 * Using any here seems fine so far.
 */
type ReactHookFormContext = any;
/**
 * The react-hook-form useForm returnType,
 *  amended with our custom function to validate a field name.
 */
export type FormReturn<TFieldValues extends FieldValues> = UseFormReturn<TFieldValues, ReactHookFormContext> & {
    fieldName: FieldNameGetter<TFieldValues>;
};
/**
 * Wrapper around react-hook-form's useForm.
 *
 * Should behave like the original function, only exposing a "fieldName"
 *  function on top which is used to validate field names.
 */
export declare const useHookForm: <TFieldValues extends FieldValues>(props?: Partial<{
    mode: "onBlur" | "onChange" | "onSubmit" | "all" | "onTouched";
    disabled: boolean;
    reValidateMode: "onBlur" | "onChange" | "onSubmit";
    defaultValues: ((payload?: unknown) => Promise<TFieldValues>) | import("react-hook-form").DefaultValues<TFieldValues>;
    values: TFieldValues;
    errors: import("react-hook-form").FieldErrors<TFieldValues>;
    resetOptions: Partial<{
        keepDirtyValues: boolean;
        keepErrors: boolean;
        keepDirty: boolean;
        keepValues: boolean;
        keepDefaultValues: boolean;
        keepIsSubmitted: boolean;
        keepIsSubmitSuccessful: boolean;
        keepTouched: boolean;
        keepIsValidating: boolean;
        keepIsValid: boolean;
        keepSubmitCount: boolean;
    }> | undefined;
    resolver: import("react-hook-form").Resolver<TFieldValues, any>;
    context: any;
    shouldFocusError: boolean;
    shouldUnregister: boolean;
    shouldUseNativeValidation: boolean;
    progressive: boolean;
    criteriaMode: import("react-hook-form").CriteriaMode;
    delayError: number;
}> | undefined) => FormReturn<TFieldValues>;
export declare const useHookFormFieldArray: typeof useFieldArray;
export {};
